# -*- coding: utf-8 -*-
"""
CREATED
    @author: Morten Lybech Thøgersen, 2023-05-22, mlt@emd.dk

PURPOSE:
    An example on howto execute on-demand mesoscale calculations through the EMD-API.
    This is a minimal example by use of the python requests package. The data returned is a .mesores file.
    Obtain the results from by use of the file emdwrfod_example_order_check.py

    This file is a part of set of 3 example files each with a specific focus:
       1. Status and overview of user-request and past-calculations (emdwrfod_example_status.py)
       2. Submit a calculation (emdwrfod_example_order_submit.py)
       3. Check status and retrieve data from one or more calculations (emdwrfod_example_order_check.py)

USAGE:
    1. Obtain a API access token from EMD (contact sales@emd.dk)
    2. Purchase some calculation-credits (1 credit is worth 1 month of mesoscale-timeseries for the basic configuration)
    3. Run this script and inspect the results

REFERENCES:
    .mesores documentation with samples:
       https://help.emd.dk/knowledgebase/
       https://www.emd.dk/files/flow/EMD_technote_MESORES_20230426.pdf
    UI: https://api.emd.dk/emd-wrf-od/ui

"""

import requests
import json
import tabulate


if __name__ == '__main__':

    # Input data: URL, Access-Token and Model-Id
    api_url = "https://aapi.emd.dk/emd-wrf-od"
    user_token = '16d5e6de-74da-4d03-a06c-ee1942417959' # EMD-API OD TEST USER

    # Input data: Locations for EMD-WRF OD execution - here we request data multiple locations
    locations = { "denmark_strandby_1pt": {"longitude": 10.50, "latitude": 57.50, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "1 point", "model": 'emd_36_3km_era5hourly_glob'},
                  "ireland_cork_9pts": {"longitude": -8.49, "latitude": 51.80, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "9 points", "model": 'emd_36_3km_era5hourly_glob'},
                  "brazil_barragrande_25pts": {"longitude": -41.41, "latitude": -2.91, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "25 points", "model": 'emd_36_3km_era5hourly_glob'},
                  "newzealand_wellington_1pt": {"longitude": -174.69, "latitude": -41.26, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "1 point", "model": 'emd_36_3km_era5hourly_glob'},
                  "frenchpolynesia_fakarava_9pts": {"longitude": -145.63, "latitude": -16.24, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "9 points", "model": 'emd_36_3km_era5hourly_glob'},
                  "austria_badgastein_25pts": {"longitude": 13.14, "latitude": 47.12, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "25 points", "model": 'emd_36_3km_era5hourly_glob'},
                  "sweden_storrotliden_ice_1pt": {"longitude": 18.37, "latitude": 64.23, "date_from": "2010-01-01", "date_to": "2010-01-31", "points": "1 point", "model": 'emd_36_3km_era5hourly_icing_glob'} }

    # Submitting calculations
    order_list = []
    for key, value in locations.items():
        response_submit = requests.post(url = api_url+"/order_points",
                                        params={ "lat": value["latitude"], "lon": value["longitude"],
                                                 "start_date": value["date_from"], "end_date": value["date_to"],
                                                 "model_id": value["model"], "area": value["points"] },
                                        headers = { 'X-Auth': user_token },  verify = True)
        order_status = json.loads(response_submit.content)
        order_list.append( [key, order_status['credits'], order_status['order_id']] )

    print(tabulate.tabulate(order_list, headers=["Location", "Credits", "Order_ID"]))
